@@ -1,31 +1,28 @@
-#' Plot a dot plot with matched shapes on a box plot using four variables.
+#' Plot scatter plot with bar & error bars for 2-way ANOVAs with or without a blocking factor.
 #'
-#' The functions \code{\link{plot_3d_scatterbar}}, \code{\link{plot_3d_scatterbox}}, \code{\link{plot_4d_scatterbar}}  and \code{\link{plot_4d_scatterbox}} are useful for plotting one-way or two-way ANOVA designs with randomised blocks or repeated measures. The blocks or subjects can be mapped to the `shapes` argument in both functions (up to 25 levels can be mapped to `shapes`; there will be an error if this number is exceeded). The 3d versions use the categorical variable (`xcol`) for grouping (e.g. one-way ANOVA designs), and 4d versions take an additional grouping variable (e.g. two-way ANOVA designs) that is passed to either `boxes` or `bars` argument.
+#' There are 4 related functions for 2-way ANOVA type plots. In addition to a categorical variable along the X-axis, a grouping factor is passed to either `points`, `bars` or `boxes` argument in these functions. A blocking factor (or any other categorical variable) can be optionally passed to the `shapes` argument.
+#' 1. \code{\link{plot_4d_point_sd}} (mean & SD, SEM or CI95 error bars)
+#' 2. \code{\link{plot_4d_scatterbar}} (bar & SD, SEM or CI95 error bars)
+#' 3. \code{\link{plot_4d_scatterbox}} (box & whiskers)
+#' 4. \code{\link{plot_4d_scatterviolin}} (box & whiskers, violin)
 #' 
-#' These functions rely on \code{\link[ggplot2]{ggplot}} with \code{\link[ggplot2]{geom_point}} and \code{\link[ggplot2]{geom_bar}} (through \code{stat_summary}) or \code{\link[ggplot2]{geom_boxplot}} geometries.
-#'
-#' Variables other than the quantitative variable (`ycol`) will be automatically converted to categorical variables even if they are numeric in the data table.
 #' 
-#' Shapes are always plotted in black colour, and their opacity can be changed with the `s_alpha` argument and overlap can be reduced with the `jitter` argument. Other arguments are similar to other plot functions as briefly explained below.
-#'
-#' Bars depict means using \code{\link[ggplot2]{stat_summary}} with \code{geom = "bar", fun = "mean"} , and bar width is set to 0.7 (cannot be changed). Error bar width can be changed with the `ewid` argument.
+#' These can be especially useful when the fourth variable `shapes` is a random factor or blocking factor (up to 25 levels are allowed; there will be an error with more levels). The `shapes` argument can be left blank to plot ordinary 2-way ANOVAs without blocking. 
 #' 
-#' Boxplot geometry uses \code{\link[ggplot2]{geom_boxplot}} with \code{position = position_dodge(width = 0.9), width = 0.6}. The thick line within the boxplot depicts the median, the box the IQR (interquartile range) and the whiskers show 1.5*IQR.
-#' 
-#' In 4d versions, the two grouping variables (i.e. `xcol` and either `boxes` or `bars`) are passed to ggplot aesthetics through \code{group = interaction{ xcol, shapes}}. 
+#' In `plot_4d_point_sd` and `plot_4d_scatterbar`, the default error bar is SD (can be changed to SEM or CI95). In `plot_4d_point_sd`, a large coloured symbol is plotted at the mean, all other data are shown as smaller symbols. Boxplot uses \code{\link[ggplot2]{geom_boxplot}} to depict median (thicker line), box (interquartile range (IQR)) and the whiskers (1.5*IQR).
 #'  
 #' Colours can be changed using `ColPal`, `ColRev` or `ColSeq` arguments. 
 #' `ColPal` can be one of the following: "okabe_ito", "dark", "light", "bright", "pale", "vibrant,  "muted" or "contrast".
 #' `ColRev` (logical TRUE/FALSE) decides whether colours are chosen from first-to-last or last-to-first from within the chosen palette. 
 #' `ColSeq` (logical TRUE/FALSE) decides whether colours are picked by respecting the order in the palette or the most distant ones using \code{\link[grDevices]{colorRampPalette}}.
 #' 
-#' All four functions can be expanded further, for example with \code{\link[ggplot2]{facet_grid}} or \code{\link[ggplot2]{facet_wrap}}.
-#'
+#' The resulting `ggplot2` graph can take additional geometries or other layers. 
+#' 
 #' @param data a data table, e.g. data.frame or tibble.
 #' @param xcol name of the column with the categorical factor to plot on X axis. If column is numeric, enter as \code{factor(col)}.
 #' @param ycol name of the column to plot on quantitative variable on the Y axis.
 #' @param bars name of the column containing grouping within the factor plotted on X axis. Can be categorical or numeric X. If your table has numeric X and you want to plot as factor, enter \code{xcol = factor(name of colum)}.
-#' @param shapes name of the column that contains matched observations, e.g. subject IDs, experiment ID.
+#' @param shapes name of the column that contains matched observations (e.g. subject IDs, experiment number) or another variable to pass on to symbol shapes. If not provided, the shapes for all groups is the same.
 #' @param facet add another variable from the data table to create faceted graphs using \code{ggplot2}[facet_wrap].
 #' @param ErrorType select the type of error bars to display. Default is "SD" (standard deviation). Other options are "SEM" (standard error of the mean) and "CI95" (95% confidence interval based on t distributions).
 #' @param symsize size of symbols, default set to 3.
@@ -54,25 +51,19 @@
 #' @import ggplot2
 #'
 #' @examples
-#' #3d version for 1-way data with blocking
-#' plot_3d_scatterbox(data = data_1w_death, 
-#' xcol = Genotype, ycol = Death, shapes = Experiment)
-#' #compare above graph to
-#' plot_scatterbox(data = data_1w_death, xcol = Genotype, ycol = Death)
-#' 
 #' #4d version for 2-way data with blocking
-#' plot_4d_scatterbox(data = data_2w_Tdeath, 
+#' plot_4d_scatterbar(data = data_2w_Tdeath, 
 #' xcol = Genotype, 
 #' ycol = PI, 
-#' boxes = Time, 
+#' bars = Time, 
 #' shapes = Experiment)
 #' 
-#' plot_4d_scatterbar(data = data_2w_Festing, 
-#' xcol = Strain, 
-#' ycol = GST, 
-#' bars = Treatment, 
-#' shapes = Block)
-#'
+#' #4d version without blocking factor
+#' #`shapes` can be left blank
+#' plot_4d_scatterbar(data = data_2w_Tdeath, 
+#' xcol = Genotype, 
+#' ycol = PI, 
+#' bars = Time)
 
 plot_4d_scatterbar <- function(data, xcol, ycol, bars, shapes, facet, ErrorType = "SD", symsize = 3,  s_alpha = 0.8, b_alpha = 1, bwid = 0.7, jitter = 0.1, ewid = 0.2,  TextXAngle = 0, LogYTrans, LogYBreaks = waiver(), LogYLabels = waiver(), LogYLimits = NULL, facet_scales = "fixed", fontsize = 20, group_wid = 0.8, symthick, bthick, ColPal = c("okabe_ito", "all_grafify", "bright",  "contrast",  "dark",  "fishy",  "kelly",  "light",  "muted",  "pale",  "r4",  "safe",  "vibrant"), ColRev = FALSE, ColSeq = TRUE, ...){
   ColPal <- match.arg(ColPal)
@@ -84,28 +75,39 @@ plot_4d_scatterbar <- function(data, xcol, ycol, bars, shapes, facet, ErrorType
   if (missing(bthick)) {bthick = fontsize/22}
   if (missing(symthick)) {symthick = fontsize/22}
   suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
-                                 y = {{ ycol }},
-                                 group = interaction(factor({{ bars }}),
-                                                     factor({{ xcol }}))))+
-    stat_summary(geom = "bar", 
-                 colour = "black", 
-                 width = bwid, 
-                 alpha = b_alpha, 
-                 linewidth = bthick,
-                 aes(fill = factor({{ bars }})),
-                 position = position_dodge(width = group_wid),
-                 fun = "mean", ...)+
-    geom_point(size = symsize, 
-               alpha = s_alpha, 
-               stroke = symthick, 
-               colour = "black",
-               position = position_jitterdodge(jitter.width = jitter,
-                                               dodge.width = group_wid),
-               aes(shape = factor({{ shapes }})), ...)+
-    scale_shape_manual(values = 0:25)+
-    labs(fill = enquo(bars),
-         x = enquo(xcol),
-         shape = enquo(shapes)))
+                                                  y = {{ ycol }},
+                                                  group = interaction(factor({{ bars }}),
+                                                                      factor({{ xcol }}))))+
+                     stat_summary(geom = "bar", 
+                                  colour = "black", 
+                                  width = bwid, 
+                                  alpha = b_alpha, 
+                                  linewidth = bthick,
+                                  aes(fill = factor({{ bars }})),
+                                  position = position_dodge(width = group_wid),
+                                  fun = "mean", ...))
+  if(missing(shapes)){
+    suppressWarnings(P <- P +
+                       geom_point(size = symsize, 
+                                  alpha = s_alpha, 
+                                  stroke = symthick, 
+                                  colour = "black",
+                                  position = position_jitterdodge(jitter.width = jitter,
+                                                                  dodge.width = group_wid),
+                                  aes(fill = factor({{ bars }})), 
+                                  shape = 21, ...))
+  } else {
+    suppressWarnings(P <- P + 
+                       geom_point(size = symsize, 
+                                  alpha = s_alpha, 
+                                  stroke = symthick, 
+                                  colour = "black",
+                                  position = position_jitterdodge(jitter.width = jitter,
+                                                                  dodge.width = group_wid),
+                                  aes(shape = factor({{ shapes }})),
+                                  ...)+
+                       scale_shape_manual(values = 0:25))
+  }
   if(ER == "mean_cl_normal") {
     P <- P + 
       stat_summary(geom = "errorbar", 
@@ -116,12 +118,12 @@ plot_4d_scatterbar <- function(data, xcol, ycol, bars, shapes, facet, ErrorType
                    position = position_dodge(width = group_wid), ...)
   } else {
     P <- P + stat_summary(geom = "errorbar", 
-                 colour = "black", 
-                 size = bthick, 
-                 width = ewid,
-                 fun.data = ER,
-                 fun.args = list(mult = 1),
-                 position = position_dodge(width = group_wid), ...)
+                          colour = "black", 
+                          linewidth = bthick, 
+                          width = ewid,
+                          fun.data = ER,
+                          fun.args = list(mult = 1),
+                          position = position_dodge(width = group_wid), ...)
   }
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
@@ -156,6 +158,9 @@ plot_4d_scatterbar <- function(data, xcol, ycol, bars, shapes, facet, ErrorType
                            ...)}
   }
   P <- P +
+    labs(x = enquo(xcol),
+         fill = enquo(bars),
+         shape = enquo(shapes))+
     theme_grafify(base_size = fontsize)+
     guides(x = guide_axis(angle = TextXAngle),
            fill = guide_legend(order = 1),
