@@ -1,8 +1,11 @@
 #' Plot a dotplot on a boxplot with two variables.
 #'
-#' There are three types of `plot_dot_` functions that plot "dots" as data symbols plotted with \code{\link[ggplot2]{geom_dotplot}} geometry. Variants can show summary and data distributions as bar and SD errors (\link{plot_dotbar_sd}; or SEM or CI95 error bars), box and whisker plots (\link{plot_dotbox}) or violin and box & whiskers plots (\link{plot_dotviolin}). They all take a data table, a categorical X variable and a numeric Y variable. 
+#' There are three types of `plot_dot_` functions that plot data as "dots" using the \code{\link[ggplot2]{geom_dotplot}} geometry. They all take a data table, a categorical X variable and a numeric Y variable. 
+#' 1. \link{plot_dotbar_sd} (bar & SD, SEM or CI95 error bars)
+#' 2. \link{plot_dotbox} (box & whiskers)
+#' 3. \link{plot_dotviolin} (box & whiskers, violin)
 #' 
-#' Related `plot_scatter_` variants show data symbols using the \code{\link[ggplot2]{geom_point}} geometry. These are \link{plot_scatterbar_sd} (or SEM or CI95 error bars), \link{plot_scatterbox} and \link{plot_scatterviolin}. Overplotting in `plot_scatter` variants can be reduced with the `jitter` argument.
+#' Related `plot_scatter_` variants show data symbols using the \code{\link[ggplot2]{geom_point}} geometry. These are \link{plot_scatterbar_sd} (or SEM or CI95 error bars), \link{plot_scatterbox} and \link{plot_scatterviolin}. Over plotting in `plot_scatter` variants can be reduced with the `jitter` argument.
 #' 
 #' The X variable is mapped to the \code{fill} aesthetic of dots, symbols, bars, boxes and violins.
 #' 
@@ -55,11 +58,12 @@ plot_dotbox <- function(data, xcol, ycol, facet, dotsize = 1.5, d_alpha = 0.8, b
   ColPal <- match.arg(ColPal)
   if (missing(bthick)) {bthick = fontsize/22}
   if (missing(dotthick)) {dotthick = fontsize/22}
+  #data[[deparse(substitute(xcol))]] <- factor(#data[[deparse(substitute(xcol))]])
   if (missing(SingleColour)) {
     suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                                     y = {{ ycol }}))+
                        geom_boxplot(aes(fill = factor({{ xcol }})), 
-                                    size = bthick,
+                                    linewidth = bthick,
                                     alpha = b_alpha,
                                     outlier.alpha = 0,
                                     width = bwid,
@@ -70,9 +74,7 @@ plot_dotbox <- function(data, xcol, ycol, facet, dotsize = 1.5, d_alpha = 0.8, b
                                     binaxis = 'y', 
                                     dotsize = dotsize,
                                     aes(fill = factor({{ xcol }})),
-                                    ...)+
-                       labs(x = enquo(xcol),
-                            fill = enquo(xcol)))
+                                    ...))
   } else {
     ifelse(grepl("#", SingleColour), 
            a <- SingleColour,
@@ -81,7 +83,7 @@ plot_dotbox <- function(data, xcol, ycol, facet, dotsize = 1.5, d_alpha = 0.8, b
                   a <- SingleColour))
     suppressWarnings(P <- ggplot2::ggplot(data, aes(x = factor({{ xcol }}),
                                                     y = {{ ycol }}))+
-                       geom_boxplot(size = bthick,
+                       geom_boxplot(linewidth = bthick,
                                     alpha = b_alpha,
                                     outlier.alpha = 0,
                                     width = bwid,
@@ -93,8 +95,7 @@ plot_dotbox <- function(data, xcol, ycol, facet, dotsize = 1.5, d_alpha = 0.8, b
                                     binaxis = 'y', 
                                     dotsize = dotsize,
                                     fill = a,
-                                    ...)+
-                       labs(x = enquo(xcol)))
+                                    ...))
   }
   if(!missing(facet)) {
     P <- P + facet_wrap(vars({{ facet }}), 
@@ -129,6 +130,8 @@ plot_dotbox <- function(data, xcol, ycol, facet, dotsize = 1.5, d_alpha = 0.8, b
                            ...)}
   }
   P <- P + 
+    labs(x = enquo(xcol),
+         fill = enquo(xcol))+
     theme_grafify(base_size = fontsize)+
     guides(x = guide_axis(angle = TextXAngle))+
     scale_fill_grafify(palette = ColPal, 
