@@ -68,14 +68,14 @@ plot_xy_NumGroup <- function(data, xcol, ycol, NumGroup, facet, Boxplot = FALSE,
       geom_boxplot(aes(group = interaction({{ xcol }},
                                            {{ NumGroup }}),
                        fill = {{ NumGroup }}),
-                   size = bthick,
+                   linewidth = bthick,
                    outlier.alpha = 0,
                    width = bwid,
                    alpha = b_alpha,
                    position = position_identity(),
                    show.legend = FALSE)+
       stat_summary(geom = "line",
-                   size = bthick,
+                   linewidth = bthick,
                    alpha = l_alpha,
                    colour = "grey35",
                    fun = "median")+
