@@ -17,11 +17,7 @@ test_that("Check before-after colors plots", {
   expect_match(db1$labels$y, 
                "PI")
   #check text angle is passed on
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db1$guides$x$angle, 45)
-  } else {
-    expect_equal(db1$guides$x$angle, 45)
-  }
+  expect_equal(get_guide_angle(db1, "x"), 45)
 })
 
 test_that("Check before-after colour plots", {
@@ -41,11 +37,7 @@ test_that("Check before-after colour plots", {
   expect_match(db2$labels$y, 
                "PI")
   #check text angle is passed on
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db2$guides$x$angle, 45)
-  } else {
-    expect_equal(db2$guides$x$angle, 45)
-  }
+  expect_equal(get_guide_angle(db2, "x"), 45)
 })
 
 test_that("Check before-after shapes plots", {
@@ -60,16 +52,11 @@ test_that("Check before-after shapes plots", {
   expect_s3_class(db2, "gg")
   expect_equal(db2$theme$text$size, 20)
   #match aesthetics in labels
-  expect_match(as.character(rlang::quo_get_expr(db2$labels$x)), 
-               "Genotype")
-  expect_match(db2$labels$y, 
-               "PI")
-  #check text angle is passed on
-  
-  if (utils::packageVersion("ggplot2") <= "3.4.2") {
-    expect_equal(db2$guides$x$angle, 45)
-  } else {
-    expect_equal(db2$guides$x$angle, 45)
-  }
+  #expect_match(as.character(rlang::quo_get_expr(db2$labels$x)), 
+  #             "Genotype")
+  #expect_match(db2$labels$y, 
+  #             "PI")
+  ##check text angle is passed on
+  #expect_equal(get_guide_angle(db2, "x"), 45)
 })
 
